use snafu::prelude::*;
use sqlx::pool::PoolConnection;
use sqlx::Sqlite;

use crate::models::Post;
use crate::{Error, GeneralDatabaseSnafu};

/// Insert a new post or update an old one with the same GUID.
///
/// # Errors
///
/// An error occurs if the statement cannot be executed.
pub async fn insert_item(mut conn: PoolConnection<Sqlite>, post: &Post) -> Result<(), Error> {
    sqlx::query!(
        "insert or ignore into posts (guid, title, url, pub_date, content) values (?, ?, ?, ?, ?)",
        post.guid,
        post.title,
        post.url,
        post.pub_date,
        post.content
    )
    .execute(&mut conn)
    .await
    .context(GeneralDatabaseSnafu)?;

    Ok(())
}
